@@ -31,4 +31,18 @@ mod tests {
         let series = TimeSeries::new(demanda.to_vec());
         Page::single(series.plot().as_ref()).save("seriedemanda.svg").unwrap();
     }
+
+    use crate::time_series::Season;
+    #[test]
+    fn test_season() {
+        let demanda = [120.0, 80.0, 70.0, 60.0, 70.0, 90.0, 90.0,
+        60.0, 70.0, 80.0, 100.0, 120.0, 70.0, 40.0, 60.0, 50.0, 90.0];
+        let series = TimeSeries::new(demanda.to_vec());
+        Page::single(
+            series.plot().as_ref()
+        ).save("serie_total.svg").unwrap();
+        Page::single(
+            Season::new(&series, 12).set_season(2).plot().as_ref()
+        ).save("seriedemanda_anio_2.svg").unwrap();
+    }
 }
